mailr3439 - /1.3/prompt/molecule.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 04, 2007 - 19:33:
Author: bugman
Date: Sun Nov  4 19:33:54 2007
New Revision: 3439

URL: http://svn.gna.org/viewcvs/relax?rev=3439&view=rev
Log:
Implemented the molecule.delete() user function.


Modified:
    1.3/prompt/molecule.py

Modified: 1.3/prompt/molecule.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/prompt/molecule.py?rev=3439&r1=3438&r2=3439&view=diff
==============================================================================
--- 1.3/prompt/molecule.py (original)
+++ 1.3/prompt/molecule.py Sun Nov  4 19:33:54 2007
@@ -150,33 +150,33 @@
         molecule.copy(pipe_from=pipe_from, mol_from=mol_from, 
pipe_to=pipe_to, mol_to=mol_to)
 
 
-    def delete(self, res_id=None):
-        """Function for deleting residues.
-
-        Keyword Arguments
-        ~~~~~~~~~~~~~~~~~
-
-        res_id:  The residue identifier string.
+    def delete(self, mol_id=None):
+        """Function for deleting molecules.
+
+        Keyword Arguments
+        ~~~~~~~~~~~~~~~~~
+
+        mol_id:  The molecule identifier string.
 
 
         Description
         ~~~~~~~~~~~
 
-        This function can be used to delete a single or sets of residues.
-        """
-
-        # Function intro text.
-        if self.__relax__.interpreter.intro:
-            text = sys.ps3 + "residue.delete("
-            text = text + "res_id=" + `res_id` + ")"
-            print text
-
-        # The residue identifier argument.
-        if type(res_id) != str:
-            raise RelaxStrError, ('residue identifier', res_id)
-
-        # Execute the functional code.
-        residue.delete(res_id=res_id)
+        This function can be used to delete a single or sets of molecules.
+        """
+
+        # Function intro text.
+        if self.__relax__.interpreter.intro:
+            text = sys.ps3 + "molecule.delete("
+            text = text + "mol_id=" + `mol_id` + ")"
+            print text
+
+        # The molecule identifier argument.
+        if type(mol_id) != str:
+            raise RelaxStrError, ('molecule identifier', mol_id)
+
+        # Execute the functional code.
+        molecule.delete(mol_id=mol_id)
 
 
     def display(self, run=None):




Related Messages


Powered by MHonArc, Updated Sun Nov 04 19:40:23 2007